@@ -156,6 +156,10 @@ setMethod(
         }, so=so, names=names)
         mlt <- do.call(rbind, mlt)
         mlt$item <- factor(mlt$item, levels = colnames(x@Data$data)[which.items])
+        mlt <- within(mlt, {
+            class <- factor(class)
+            cat <- factor(cat)
+        })
         if(profile){
             if(all(x@Data$K == 2L)){
                 mlt <- mlt[mlt$cat == 'cat2', ]
