@@ -61,10 +61,11 @@ setMethod(
     }
 )
 
+#' @rdname plot-method
 setMethod(
     f = "plot",
     signature = signature(x = 'MultipleGroupClass', y = 'missing'),
-    definition = function(x, y, type = 'score', npts = 200, degrees = 45,
+    definition = function(x, y, type = 'score', npts = 200, drop2 = TRUE, degrees = 45,
                           which.items = 1:extract.mirt(x, 'nitems'),
                           rot = list(xaxis = -70, yaxis = 30, zaxis = 10),
                           facet_items = TRUE,
@@ -223,7 +224,7 @@ setMethod(
                     count <- 1
                     for(i in which.items){
                         tmp <- probtrace(extract.item(x, i, group=g), ThetaFull)
-                        if(ncol(tmp) == 2L) tmp <- tmp[,2, drop=FALSE]
+                        if(ncol(tmp) == 2L && drop2) tmp <- tmp[,2, drop=FALSE]
                         tmp2 <- data.frame(P=as.numeric(tmp), cat=gl(ncol(tmp), k=nrow(ThetaFull),
                                                                      labels=paste0('cat', 1L:ncol(tmp))))
                         P[[count]] <- tmp2
@@ -241,7 +242,7 @@ setMethod(
                 plt <- do.call(rbind, plt)
                 plt$item <- factor(plt$item, levels = colnames(x@Data$data)[which.items])
                 if(facet_items){
-                    return(xyplot(P ~ Theta|item, plt, groups = plt$cat:plt$group, ylim = c(-0.1,1.1),
+                    return(xyplot(P ~ Theta|item, plt, groups = plt$cat:factor(plt$group), ylim = c(-0.1,1.1),
                            xlab = expression(theta), ylab = expression(P(theta)),
                            auto.key = auto.key, type = 'l', main = 'Item trace lines',
                            par.strip.text=par.strip.text, par.settings=par.settings, ...))
